package cn.pluss.platform.mapper;

import java.util.List;
import java.util.Map;
import org.apache.ibatis.annotations.Mapper;
import cn.pluss.platform.entity.MerchantRegistAuditRecord;

@Mapper
public interface MerchantRegistAuditRecordMapper {

    public MerchantRegistAuditRecord queryMerchantRegistAuditRecord(MerchantRegistAuditRecord merchantRegistAuditRecord);

    public List<MerchantRegistAuditRecord> queryMerchantRegistAuditRecordList(MerchantRegistAuditRecord merchantRegistAuditRecord);

    public void saveMerchantRegistAuditRecord(MerchantRegistAuditRecord merchantRegistAuditRecord);

    public void updateMerchantRegistAuditRecord(MerchantRegistAuditRecord merchantRegistAuditRecord);

    public void deleteMerchantRegistAuditRecord(MerchantRegistAuditRecord merchantRegistAuditRecord);

    public List<MerchantRegistAuditRecord> queryMerchantRegistAuditRecordPage(Map map);

    public Integer queryMerchantRegistAuditRecordPageCount(Map map);

    public void saveMerchantRegistAuditRecordBatch(List<MerchantRegistAuditRecord>  merchantRegistAuditRecordList);
}

