package cn.pluss.platform.controller;

import cn.pluss.platform.api.PageInfo;
import cn.pluss.platform.api.Result;
import cn.pluss.platform.api.ResultGenerator;
import cn.pluss.platform.constants.ProjectConstant;
import cn.pluss.platform.entity.MerchantRegistAuditRecord;
import cn.pluss.platform.merchantRegistAuditRecord.MerchantRegistAuditRecordService;
import cn.pluss.platform.util.StringUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.List;
import java.util.Map;


@RestController
@RequestMapping("/merchantRegistAuditRecord")
@Transactional
@Api(value = "MerchantRegistAuditRecord控制类", tags = {"MerchantRegistAuditRecord接口"})
public class MerchantRegistAuditRecordController {

    @Resource
    private MerchantRegistAuditRecordService merchantRegistAuditRecordService;

    @GetMapping
    @ApiOperation(value = "获取全部", notes = "返回分页过后的数据", httpMethod = "GET")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "page", value = "查询页码", paramType = "query", dataType = "Integer", defaultValue = "0"),
            @ApiImplicitParam(name = "size", value = "每页数据量", paramType = "query", dataType = "Integer", defaultValue = "0")
    })
    public Result<PageInfo<MerchantRegistAuditRecord>> list(@RequestParam(defaultValue = "1") Integer page, @RequestParam(defaultValue = "10") Integer size) {
        if (size == null || size == 0) {
            size = ProjectConstant.PAGE_SIZE;
        }
        if (page == null || page == 0) {
            page = 1;
        }
        Map<String, Object> map = new HashMap<String, Object>();
        map.put("pageSize", size);
        map.put("offset", (page - 1) * size);
        List<MerchantRegistAuditRecord> merchantRegistAuditRecordList = merchantRegistAuditRecordService.queryMerchantRegistAuditRecordPage(map);
        Integer count = merchantRegistAuditRecordService.queryMerchantRegistAuditRecordPageCount(map);
        //返回参数
        PageInfo pager = new PageInfo<MerchantRegistAuditRecord>(count.longValue(), (long) StringUtil.getPageCount(count, size), page.longValue(), size.longValue(), merchantRegistAuditRecordList);
        return ResultGenerator.genSuccessResult(pager);
    }

    @PostMapping
    @ApiOperation(value = "添加数据", notes = "添加新的数据", httpMethod = "POST")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "MerchantRegistAuditRecord", value = "待添加的MerchantRegistAuditRecord实例", paramType = "body", dataType = "MerchantRegistAuditRecord", required = true)
    })
    public Result add(@RequestBody MerchantRegistAuditRecord merchantRegistAuditRecord) {
        merchantRegistAuditRecordService.saveMerchantRegistAuditRecord(merchantRegistAuditRecord);
        return ResultGenerator.genSuccessResult();
    }

    @DeleteMapping("/{id}")
    @ApiOperation(value = "删除数据", notes = "根据id删除数据", httpMethod = "DELETE")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "id", value = "查询的id实例", paramType = "path", dataType = "Integer", required = true)
    })
    public Result delete(@PathVariable Integer id) {
        MerchantRegistAuditRecord merchantRegistAuditRecord = new MerchantRegistAuditRecord();
        merchantRegistAuditRecord.setId(id.intValue());
        merchantRegistAuditRecordService.deleteMerchantRegistAuditRecord(merchantRegistAuditRecord);
        return ResultGenerator.genSuccessResult();
    }

    @PutMapping
    @ApiOperation(value = "更新数据", notes = "根据内容更新数据", httpMethod = "PUT")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "MerchantRegistAuditRecord", value = "更新的MerchantRegistAuditRecord实例", paramType = "body", dataType = "MerchantRegistAuditRecord", required = true)
    })
    public Result update(@RequestBody MerchantRegistAuditRecord merchantRegistAuditRecord) {
        merchantRegistAuditRecordService.updateMerchantRegistAuditRecord(merchantRegistAuditRecord);
        return ResultGenerator.genSuccessResult();
    }

    @GetMapping("/{id}")
    @ApiOperation(value = "获取单个值", notes = "查看单个项目的内容", httpMethod = "GET")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "id", value = "查询的id", paramType = "path", required = true, dataType = "Integer", defaultValue = "0")
    })
    public Result detail(@PathVariable Long id) {
        MerchantRegistAuditRecord merchantRegistAuditRecord = new MerchantRegistAuditRecord();
        merchantRegistAuditRecord.setId(id.intValue());
        merchantRegistAuditRecord = merchantRegistAuditRecordService.queryMerchantRegistAuditRecord(merchantRegistAuditRecord);
        return ResultGenerator.genSuccessResult(merchantRegistAuditRecord);
    }

}

